@@ -675,7 +675,7 @@ init_data_structure3 (data_fmt * data, option_fmt *options)
         for (pop = 0; pop < data->numpop; pop++)
             maxi += data->numalleles[pop][locus];
         data->allele[locus] =
-            (char **) mycalloc (1, sizeof (char*) * maxi);
+            (char **) mycalloc (maxi+1, sizeof (char*));
         for (pop = 0; pop < maxi; pop++)
 	  data->allele[locus][pop] =
             (char *) mycalloc (options->allelenmlength+1, sizeof (char));
@@ -2764,7 +2764,7 @@ create_alleles (data_fmt * data, option_fmt *options)
 		  }
 	    }
         }
-	if(z==0)
+	if(z<=1)
 	  {
 	    data->skiploci[locus] = TRUE;// this skips loci with _no_ data
 	    continue;
