@@ -215,10 +215,10 @@ MYREAL find_beta_truncgamma(MYREAL mean, MYREAL alpha, MYREAL lower, MYREAL uppe
 MYREAL
 propose_gamma_newparam (MYREAL param, long which, bayes_fmt * bayes, MYREAL *r)
 {
-  const MYREAL delta = bayes->delta[which];
+  //const MYREAL delta = bayes->delta[which];
   const MYREAL lower = bayes->minparam[which];
   const MYREAL upper = bayes->maxparam[which];
-  const MYREAL mean = bayes->meanparam[which];
+  //const MYREAL mean = bayes->meanparam[which];
   MYREAL alpha = bayes->alphaparam[which];
   MYREAL beta = bayes->betaparam[which];
   return trunc_gamma_rand(alpha, beta, lower, upper);
