@@ -37,7 +37,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
  
-$Id: random.c 2158 2013-04-29 01:56:20Z beerli $
+$Id: random.c 2169 2013-08-24 19:02:04Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include <stdlib.h>
@@ -475,7 +475,7 @@ unsigned long int random_seed()
   return(seed);
 }
 
-void set_seed(long autoseed, long * inseed)
+void set_seed(long autoseed, unsigned long * inseed)
 {
   unsigned long timeseed = 0;
    switch (autoseed)
@@ -495,7 +495,7 @@ void set_seed(long autoseed, long * inseed)
             break;
         }
 #endif
-      *inseed = abs((long) timeseed);
+      *inseed = (unsigned long) abs((long)timeseed);
       break;
     case NOAUTO:
     case NOAUTOSELF:
@@ -530,6 +530,14 @@ void getseed_lcg (option_fmt *options)
     set_seed(options->autoseed, &options->inseed);
     options->saveseed = options->inseed;
     init_lcg(options);
+    if(options->randomsubset>0 && options->randomsubsetseed > 0)
+      {
+#ifdef WIN32
+	srand(options->randomsubsetseed);
+#else
+	srand48(options->randomsubsetseed);
+#endif
+      }
 }
 
 void getseed_mt (option_fmt *options)
@@ -573,7 +581,7 @@ void getseed_quasi (option_fmt *options)
 /// and distributes them to the workers.
 void getseed(option_fmt *options)
 {
-  long test = -1;
+  //long test = -1;
   long i;
   long worker;
   long *newseeds;
