@@ -31,7 +31,7 @@
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
  
- $Id: sequence.c 2158 2013-04-29 01:56:20Z beerli $
+ $Id: sequence.c 2170 2013-09-19 12:08:27Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
@@ -357,7 +357,7 @@ void
 make_sequences (world_fmt * world, option_fmt * options, data_fmt * data,
                 long locus)
 {
-    if (world->sumtips==0)
+    if (world->sumtips<=1)
       {
 	data->skiploci[locus] = TRUE;
         world->data->skiploci[locus] = TRUE;
@@ -1046,14 +1046,14 @@ void
 sitesort2 (world_fmt * world, data_fmt * data, option_fmt *options, long sites, long locus)
 {
   long gap, i, i1, j, jj, jg, k, kk, kkk, itemp, pop, z = 0;
-    boolean flip, tied, samewt;
-    seqmodel_fmt *seq;
-    long *tempsum, *temppop;
-    long numind;
-    MYREAL a1,a2;
-    tempsum = (long *) mycalloc (1, sizeof (long) * data->numpop);
-    temppop = (long *) mycalloc (1, sizeof (long) * data->numpop);
-    for (i = 0; i < data->numpop; i++)
+  boolean flip, tied, samewt;
+  seqmodel_fmt *seq;
+  long *tempsum, *temppop;
+  long numind;
+  MYREAL a1,a2;
+  tempsum = (long *) mycalloc (1, sizeof (long) * data->numpop);
+  temppop = (long *) mycalloc (1, sizeof (long) * data->numpop);
+  for (i = 0; i < data->numpop; i++)
     {
       if(options->randomsubset > 0)
 	{
@@ -1063,15 +1063,15 @@ sitesort2 (world_fmt * world, data_fmt * data, option_fmt *options, long sites,
 	{
 	  numind = data->numind[i][locus] ;
 	}
-      if (numind > 0)
-        {
+      //      if (numind > 0)
+      //  {
 	  temppop[z] = i;
 	  if (z == 0)
 	    tempsum[z] = numind;
 	  else
 	    tempsum[z] = tempsum[z - 1] + numind;
-            z++;
-        }
+          z++;
+	    //  }
     }
     seq = world->data->seq[0];
     gap = sites / 2;
@@ -1108,13 +1108,17 @@ sitesort2 (world_fmt * world, data_fmt * data, option_fmt *options, long sites,
                         kk++;
                     }
 		    i1 = temppop[pop];
-		    kkk = data->shuffled[i1][locus][kk];
-		    a1 = data->yy[i1][kkk][locus][0][jj - 1];
-		    a2 = data->yy[i1][kkk][locus][0][jg - 1];
-                    flip =
-                        (a1 > a2);
-                    tied = (tied
-                            && a1 == a2);
+		    //debug1
+		    if (data->numind[i1][locus]>0)
+		      {
+			kkk = data->shuffled[i1][locus][kk];
+			a1 = data->yy[i1][kkk][locus][0][jj - 1];
+			a2 = data->yy[i1][kkk][locus][0][jg - 1];
+			flip =
+			  (a1 > a2);
+			tied = (tied
+				&& a1 == a2);
+		      }
                     k++;
                 }
                 if (!flip)
@@ -1138,7 +1142,7 @@ sitesort2 (world_fmt * world, data_fmt * data, option_fmt *options, long sites,
 void
 sitecombine2 (world_fmt * world, data_fmt * data, option_fmt *options, long sites, long locus)
 {
-    long i, j, k, kk, pop, z = 0;
+  long i, i1, j, k, kk, pop, z = 0;
     boolean tied, samewt;
     seqmodel_fmt *seq;
     long *tempsum, *temppop;
@@ -1158,15 +1162,16 @@ sitecombine2 (world_fmt * world, data_fmt * data, option_fmt *options, long site
     for (i = 0; i < data->numpop; i++)
     {
       numind = ((options->randomsubset > 0) && (options->randomsubset < data->numind[i][locus])) ? options->randomsubset : data->numind[i][locus];
-      if (numind > 0)
-        {
+      //debug2
+      //      if (numind > 0)
+      //  {
 	  temppop[z] = i;
 	  if (z == 0)
 	    tempsum[z] = numind;
 	  else
                 tempsum[z] = tempsum[z - 1] + numind;
             z++;
-        }
+	    //  }
     }
 
     seq = world->data->seq[0];
@@ -1198,23 +1203,27 @@ sitecombine2 (world_fmt * world, data_fmt * data, option_fmt *options, long site
                 {
                     kk++;
                 }
-		kkk = data->shuffled[pop][locus][kk];
-                tied = (tied
-                        && data->yy[temppop[pop]][kkk][locus][0][seq->
-                                                                alias[i - 1] -
-                                                                1] ==
-                        data->yy[temppop[pop]][kkk][locus][0][seq->alias[j - 1] -
-                                                             1]);
-                k++;
-            }
-            if (!tied)
-                break;
-            seq->aliasweight[i - 1] += seq->aliasweight[j - 1];
-            seq->aliasweight[j - 1] = 0;
-            seq->ally[seq->alias[j - 1] - 1] = seq->alias[i - 1];
-            j++;
-        }
-        i = j;
+		i1 = temppop[pop];
+		if (data->numind[i1][locus]>0)
+		  {
+		    kkk = data->shuffled[i1][locus][kk];
+		    tied = (tied
+			    && data->yy[i1][kkk][locus][0][seq->
+							   alias[i - 1] -
+							   1] ==
+			    data->yy[i1][kkk][locus][0][seq->alias[j - 1] -
+							1]);
+		  }
+		k++;
+	    }
+	    if (!tied)
+	      break;
+	    seq->aliasweight[i - 1] += seq->aliasweight[j - 1];
+	    seq->aliasweight[j - 1] = 0;
+	    seq->ally[seq->alias[j - 1] - 1] = seq->alias[i - 1];
+	    j++;
+	}
+	i = j;
     }
     myfree(temppop);
     myfree(tempsum);
